@@ -16,6 +16,7 @@
 from neutron_lib.callbacks import events
 from neutron_lib.callbacks import registry
 from neutron_lib import context as nl_context
+from neutron_lib.db import api as db_api
 from neutron_lib.objects import registry as obj_reg
 from oslo_db import exception as db_exc
 from oslo_log import log as logging
@@ -49,7 +50,7 @@ class BgpDrAgentFilter(base_resource_filter.BaseResourceFilter):
             binding.agent_id = agent_id
             binding.bgp_speaker_id = bgp_speaker_id
             try:
-                with context.session.begin(subtransactions=True):
+                with db_api.CONTEXT_WRITER.using(context):
                     context.session.add(binding)
             except db_exc.DBDuplicateEntry:
                 # it's totally ok, someone just did our job!
@@ -74,7 +75,7 @@ class BgpDrAgentFilter(base_resource_filter.BaseResourceFilter):
 
     def _get_active_dragents(self, plugin, context):
         """Return a list of active BgpDrAgents."""
-        with context.session.begin(subtransactions=True):
+        with db_api.CONTEXT_READER.using(context):
             active_dragents = plugin.get_agent_objects(
                 context, filters={
                     'agent_type': [bgp_consts.AGENT_TYPE_BGP_ROUTING],
@@ -127,6 +128,8 @@ class BgpDrAgentFilter(base_resource_filter.BaseResourceFilter):
 
 class BgpDrAgentSchedulerBase(BgpDrAgentFilter):
 
+    periodic_actions = True
+
     def _register_callbacks(self):
         registry.subscribe(self.schedule_bgp_speaker_callback,
                            dr_resources.BGP_SPEAKER,
@@ -136,7 +139,7 @@ class BgpDrAgentSchedulerBase(BgpDrAgentFilter):
         """Call schedule_unscheduled_bgp_speakers for all hosts.
         """
 
-        with context.session.begin(subtransactions=True):
+        with db_api.CONTEXT_WRITER.using(context):
             query = context.session.query(agent_model.Agent.host).distinct()
             for agent in query:
                 self.schedule_unscheduled_bgp_speakers(context, agent[0])
@@ -147,7 +150,7 @@ class BgpDrAgentSchedulerBase(BgpDrAgentFilter):
         """
 
         LOG.debug('Started auto-scheduling on host %s', host)
-        with context.session.begin(subtransactions=True):
+        with db_api.CONTEXT_WRITER.using(context):
             bgp_dragent = obj_reg.load_class('Agent').get_object(
                 context,
                 agent_type=bgp_consts.AGENT_TYPE_BGP_ROUTING,
@@ -216,3 +219,20 @@ class WeightScheduler(base_scheduler.BaseWeightScheduler,
     def __init__(self):
         super(WeightScheduler, self).__init__(self)
         self._register_callbacks()
+
+
+class StaticScheduler(base_scheduler.BaseScheduler,
+                      BgpDrAgentFilter):
+
+    periodic_actions = False
+
+    def schedule_all_unscheduled_bgp_speakers(self, context):
+        return True
+
+    def schedule_unscheduled_bgp_speakers(self, context, host):
+        return True
+
+    def select(self, plugin, context, resource_hostable_agents,
+               resource_hosted_agents, num_agents_needed):
+
+        return []
